export declare type ScaleUnit = 'rem' | 'px';
export declare type Category = 'titlepiece' | 'headline' | 'body' | 'textSans';
export declare type LineHeight = 'tight' | 'regular' | 'loose';
export declare type FontWeight = 'light' | 'regular' | 'bold' | 'bolder';
export declare type FontStyle = 'normal' | 'italic';
export declare type FontWeightDefinition = {
    hasItalic: boolean;
};
export declare type Option<A> = A | null;
export declare type TypographyStyles = {
    fontFamily: string;
    fontSize: string | number;
    lineHeight: string | number;
    fontWeight?: number;
    fontStyle?: string;
};
export declare type TypographySizes = {
    [key in string]: number;
};
export interface TitlepieceSizes extends TypographySizes {
    small: number;
    medium: number;
    large: number;
}
export interface HeadlineSizes extends TypographySizes {
    xxxsmall: number;
    xxsmall: number;
    xsmall: number;
    small: number;
    medium: number;
    large: number;
    xlarge: number;
}
export interface BodySizes extends TypographySizes {
    small: number;
    medium: number;
}
export interface TextSansSizes extends TypographySizes {
    xxsmall: number;
    xsmall: number;
    small: number;
    medium: number;
    large: number;
    xlarge: number;
    xxlarge: number;
}
export declare type Fs = (category: Category) => (level: string, { lineHeight, fontWeight, fontStyle, unit, }: {
    lineHeight: LineHeight;
    fontWeight: FontWeight;
    fontStyle: Option<FontStyle>;
    unit: ScaleUnit;
}) => TypographyStyles;
export declare type FontScaleFunction = (options?: FontScaleArgs) => TypographyStyles;
export declare type FontScaleFunctionStr = (options?: FontScaleArgs) => string;
export interface FontScaleArgs {
    lineHeight?: LineHeight;
    fontWeight?: FontWeight;
    fontStyle?: FontStyle;
    unit?: ScaleUnit;
}
